{# djlint:off #}
<html>
    <body>
        <p>Click the link below to sign in to your account:</p>
        <p>
            <a href="{{ login_url }}"
               style="background-color: #007bff;
                      color: white;
                      padding: 12px 24px;
                      text-decoration: none;
                      border-radius: 4px">Sign In</a>
        </p>
        <p>This link will expire in 15 minutes.</p>
        <p>If you didn't request this, you can safely ignore this email.</p>
    </body>
</html>
{# djlint:on #}
